@@ -1,7 +1,7 @@
 """A set of components for Panel Sharing"""
-from .authentication import Authentication
 from .build_project import ProjectBuilder
 from .gallery import Gallery
+from .oauth import OAuth
 from .other import about, faq, iframe
 from .settings_editor import settings_editor
 from .share_project import ShareProject
