@@ -43,14 +43,14 @@ class ProjectBuilder(pn.viewable.Viewer):
     def _get_panel(self):
         self.convert_button = pn.widgets.Button.from_param(
             self.param.convert,
-            name="🏃 Convert",
+            name="Convert",
             sizing_mode="stretch_width",
             align="end",
             button_type="primary",
         )
         self.open_developer_link_button = pn.widgets.Button.from_param(
             self.param.open_developer_link,
-            name="🔗 OPEN",
+            name="🔗 Open",
             width=125,
             sizing_mode="fixed",
             align="end",
@@ -62,7 +62,7 @@ class ProjectBuilder(pn.viewable.Viewer):
             width=125,
             button_type="light",
             sizing_mode="fixed",
-            label="📁 DOWNLOAD",
+            label="📁 Download",
             align="end",
         )
 
